/*
 * GCLC swt, provide a swt window for console applications
 * Copyright (C) 2015-2017 E. Bigeon
 * mailto:emmanuel@bigeon.fr
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc-swt:net.bigeon.gclc.swt.SWTConsoleShell.java
 * Created on: Apr 18, 2015
 */
package net.bigeon.gclc.swt;

import java.io.BufferedReader;

/*-
 * #%L
 * GCLC swt
 * %%
 * Copyright (C) 2015 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import net.bigeon.gclc.manager.PipedConsoleInput;
import net.bigeon.gclc.manager.PipedConsoleOutput;

/** A shell containing a {@link SWTConsoleView}
 * <p>
 *
 * @author Emmanuel Bigeon */
public final class SWTConsole extends Composite {

    private ConsoleInputManager  inputManager;
    private ConsoleOutputManager outputManager;
    private ConsolePromptManager promptManager;

    /** Create the shell.
     *
     * @param parent the containing composite
     * @param style the shell style */
    public SWTConsole(final Composite parent, final int style) {
        super(parent, style);
        setLayout(new GridLayout(2, false));
        createContents();
    }

    /** Create contents of the shell. */
    private void createContents() {
        final Text output = new Text(this,
                SWT.WRAP | SWT.READ_ONLY | SWT.MULTI | SWT.V_SCROLL);
        output.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 2, 1));
        final Label prompt = new Label(this, SWT.NONE);
        prompt.setLayoutData(new GridData(SWT.LEFT, SWT.CENTER, false, false));
        final Text input = new Text(this, SWT.NONE);
        input.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false));

        inputManager = new ConsoleInputManager(input);
        outputManager = new ConsoleOutputManager(output);
        promptManager = new ConsolePromptManager(prompt);
    }

    /** Connect the console parts to the shell.
     * 
     * @param input the input
     * @param output the output
     * @param promptStream the stream where the prompts are forwarded. */
    public void connect(final PipedConsoleInput input, final PipedConsoleOutput output,
            final BufferedReader promptStream) {
        inputManager.setManager(input);
        outputManager.setManager(output);
        promptManager.setStream(promptStream);
    }

    /** @return the inputManager */
    public ConsoleInputManager getInputManager() {
        return inputManager;
    }

    /** @return the outputManager */
    public ConsoleOutputManager getOutputManager() {
        return outputManager;
    }

    /** @return the promptManager */
    public ConsolePromptManager getPromptManager() {
        return promptManager;
    }
}
