/**
 * 
 */
package net.bigeon.gclc.swt;

/*-
 * #%L
 * GCLC swt
 * %%
 * Copyright (C) 2015 - 2018 Bigeon
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * 
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * 
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * 
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.doAnswer;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import java.io.BufferedReader;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.junit.Test;
import org.mockito.invocation.InvocationOnMock;
import org.mockito.stubbing.Answer;

import net.bigeon.gclc.swt.tools.PromptReadingRunnable;

/** @author Emmanuel Bigeon */
public class PromptReadingRunnableTest {
    private final Label   view    = mock(Label.class);
    private final Display display = mock(Display.class);
    {
        when(view.getDisplay()).thenReturn(display);
        doAnswer(new Answer<Object>() {
            /* (non-Javadoc)
             * @see
             * org.mockito.stubbing.Answer#answer(org.mockito.invocation.InvocationOnMock) */
            @Override
            public Object answer(final InvocationOnMock invocation) throws Throwable {
                final Runnable runnable = invocation.getArgument(0);
                runnable.run();
                return null;
            }
        }).when(display).syncExec(any(Runnable.class));
    }

    /** Test method for {@link net.bigeon.gclc.swt.tools.PromptReadingRunnable#run()}.
     * 
     * @throws IOException if an error occurred */
    @Test
    public void testRun() throws IOException {
        final BufferedReader reader = mock(BufferedReader.class);
        when(reader.readLine()).thenReturn("abc", "def", null);

        final PromptReadingRunnable runnable = new PromptReadingRunnable(reader, view);

        runnable.run();
    }

    /** Test method for {@link net.bigeon.gclc.swt.tools.PromptReadingRunnable#run()}.
     * 
     * @throws IOException if an error occurred */
    @Test
    public void testRunWithIO() throws IOException {
        final BufferedReader reader = mock(BufferedReader.class);
        when(reader.readLine()).thenThrow(new IOException());

        final PromptReadingRunnable runnable = new PromptReadingRunnable(reader, view);
        final Logger logger = Logger.getLogger(PromptReadingRunnable.class.getName());
        final Level back = logger.getLevel();
        logger.setLevel(Level.OFF);

        runnable.run();
        logger.setLevel(back);
    }

}
